On 2014年04月10日 20:36, Eric Blake wrote:
On 04/10/2014 02:59 AM, Li Zhang wrote:
From: Li Zhang <zhlci...@linux.vnet.ibm.com>

For QEMU2.0 forward version on PPC64, it supports PCI multibus.
Currently, libvirt still disables it which causes an error
"Bus 'pci' not found".

Signed-off-by: Li Zhang <zhlci...@linux.vnet.ibm.com>
---
  src/qemu/qemu_capabilities.c | 26 ++++++++++++++++----------
  1 file changed, 16 insertions(+), 10 deletions(-)

diff --git a/src/qemu/qemu_capabilities.c b/src/qemu/qemu_capabilities.c
index 381b3ec..812bbe0 100644
--- a/src/qemu/qemu_capabilities.c
+++ b/src/qemu/qemu_capabilities.c
@@ -2813,13 +2813,16 @@ virQEMUCapsInitHelp(virQEMUCapsPtr qemuCaps, uid_t 
runUid, gid_t runGid)
                                  false) < 0)
          goto cleanup;
- /* Currently only x86_64 and i686 support PCI-multibus. */
-    if (qemuCaps->arch == VIR_ARCH_X86_64 ||
-        qemuCaps->arch == VIR_ARCH_I686) {
+    /* Currently only x86_64, i686 and PPC64 support PCI-multibus. */
+    if ((qemuCaps->arch == VIR_ARCH_PPC64 &&
+        qemuCaps->version >= 2000000) ||
+        ARCH_IS_X86(qemuCaps->arch)) {
Yuck.  Why again did you push this into qemu 2.0 without also providing
a QMP witness command to query whether the new naming is in effect?

We may be forced to take this patch, but I'm not very happy with the
situation.

I'm sorry. I make a change of the patch according to Michal's suggestion.
I add QEMU2.0 check because we still didn't find any QEMU command.

I also will wait for the witness from QEMU.
If there is a command, I will add change it accordingly.

Sorry again.



--
libvir-list mailing list
libvir-list@redhat.com
https://www.redhat.com/mailman/listinfo/libvir-list

Reply via email to